@@ -36,10 +36,6 @@ class BaseConfiguration(object):
 
     SSL_ENABLED = False
 
-    PDC_URL = 'https://pdc.fedoraproject.org/rest_api/v1'
-    PDC_INSECURE = False
-    PDC_DEVELOP = True
-
     # Users are required to be in allowed_clients to generate composes,
     # you can add group names or usernames (it can be normal user or host
     # principal) into ALLOWED_CLIENTS. The group names are from ldap for
@@ -113,7 +109,7 @@ class BaseConfiguration(object):
 
     # Select backend where message will be sent to. Currently, umb is supported
     # which means the Unified Message Bus.
-    MESSAGING_BACKEND = ''  # fedmsg or umb
+    MESSAGING_BACKEND = ''  # fedora-messaging or umb
 
     # List of broker URLs. Each of them is a string consisting of domain and
     # optiona port.
@@ -146,6 +142,21 @@ class BaseConfiguration(object):
     #   }
     # }
 
+    # Command line arguments used to construct pungi-koji command.
+    PUNGI_KOJI_ARGS = ['--nightly']
+
+    # Command line argument for raw_config source type, which overwrite
+    # arguments listed PUNGI_KOJI_ARGS.
+    # If a particular raw config should have specific pungi-koji arguments, add
+    # a key/value into this option, where key should exist in the
+    # RAW_CONFIG_URLS, and value lists each arguments.
+    # If no argument is required, just omit it, or add a key/value just as
+    # mentioned, but keep value as a empty list.
+    # RAW_CONFIG_PUNGI_KOJI_ARGS = {
+    #     'my_raw_config': ['arg1', ...],
+    #     'another_raw_config': ['arg1', ...],
+    # }
+
 
 class DevConfiguration(BaseConfiguration):
     DEBUG = True
@@ -166,6 +177,10 @@ class DevConfiguration(BaseConfiguration):
     AUTH_BACKEND = 'noauth'
     AUTH_OPENIDC_USERINFO_URI = 'https://iddev.fedorainfracloud.org/openidc/UserInfo'
 
+    KOJI_PROFILE = 'stg'
+
+    RAW_CONFIG_WRAPPER_CONF_PATH = path.join(confdir, 'raw_config_wrapper.conf')
+
 
 class TestConfiguration(BaseConfiguration):
     LOG_BACKEND = 'console'
@@ -176,7 +191,6 @@ class TestConfiguration(BaseConfiguration):
     SQLALCHEMY_DATABASE_URI = 'sqlite://'
 
     PUNGI_CONF_PATH = path.join(confdir, 'pungi.conf')
-    PUNGI_RUNROOT_KOJI_CONF_PATH = path.join(confdir, 'runroot_koji.conf')
     RAW_CONFIG_WRAPPER_CONF_PATH = path.join(confdir, 'raw_config_wrapper.conf')
     # Global network-related values, in seconds
     NET_TIMEOUT = 0
@@ -193,6 +207,7 @@ class TestConfiguration(BaseConfiguration):
     AUTH_LDAP_GROUP_BASE = 'ou=groups,dc=example,dc=com'
 
     MESSAGING_BACKEND = 'rhmsg'
+    KOJI_PROFILE = 'koji'
 
 
 class ProdConfiguration(BaseConfiguration):
