@@ -21,12 +21,13 @@
 #
 
 import requests
+from collections import defaultdict
 
-import odcs.server.utils
+from odcs.server.utils import retry, to_text_type
 from odcs.server import log
 
 import gi
-gi.require_version('Modulemd', '1.0') # noqa
+gi.require_version('Modulemd', '2.0') # noqa
 from gi.repository import Modulemd
 
 
@@ -38,32 +39,48 @@ class MBS(object):
     def __init__(self, config):
         self.mbs_url = config.mbs_url.rstrip("/")
 
-    @odcs.server.utils.retry(wait_on=(requests.ConnectionError, ), logger=log)
+    @retry(wait_on=(requests.ConnectionError, ), logger=log)
     def get_modules(self, **params):
         url = self.mbs_url + "/1/module-builds/"
         r = requests.get(url, params=params)
         r.raise_for_status()
         return r.json()
 
-    def get_latest_modules(self, nsvc):
+    def get_latest_modules(self, nsvc, include_done=False):
         """
         Query MBS and return the latest version of the module specified by nsvc.
 
         :param nsvc: N:S:V[:C] of a module to include in a compose.
+        :param include_done: When True, also module builds in the "done" state
+            are included in a result.
         :raises ModuleLookupError: if the module couldn't be found
         :return: the latest version of the module.
         """
         params = {
             "nsvc": nsvc,
-            "state": 5,  # 5 is "ready".
+            "state": [3, 5] if include_done else [5],  # 5 is "ready", 3 is "done".
             "verbose": True,  # Needed to get modulemd in response.
             "order_desc_by": "version",
         }
         modules = self.get_modules(**params)
 
+        # True if the module is "-devel" module.
+        devel_module = False
         if not modules["meta"]["total"]:
+            # In case this is "-devel" module, it won't be included in MBS,
+            # but it exists as CG build in Koji. It therefore can be used
+            # to generate the compose, but to actually find the MBS build,
+            # we need to remove the "-devel" suffix from the NSVC.
+            n = nsvc.split(":")[0]
+            if n.endswith("-devel"):
+                params["nsvc"] = n[:-len("-devel")] + params["nsvc"][len(n):]
+                modules = self.get_modules(**params)
+                devel_module = True
+
+        if not modules["meta"]["total"]:
+            state_msg = "ready or done" if include_done else "ready"
             raise ModuleLookupError(
-                "Failed to find module %s in the MBS." % nsvc)
+                "Failed to find module %s in %s state in the MBS." % (nsvc, state_msg))
 
         ret = []
         # In case the nsvc is just "name:stream", there might be multiple
@@ -76,6 +93,22 @@ class MBS(object):
         for module in modules["items"]:
             if ret and ret[0]["version"] != module["version"]:
                 break
+            if devel_module:
+                # Add -devel to module metadata in case we are composing devel
+                # module.
+                module["name"] += "-devel"
+                # Devel module always depend on the non-devel version
+                mmd = Modulemd.ModuleStream.read_string(
+                    module['modulemd'], strict=True, module_name=None, module_stream=None
+                )
+                mmd = mmd.upgrade(2)
+                for dep in mmd.get_dependencies():
+                    dep.add_runtime_stream(
+                        mmd.get_module_name(), mmd.get_stream_name()
+                    )
+                mod_index = Modulemd.ModuleIndex.new()
+                mod_index.add_module_stream(mmd)
+                module["modulemd"] = to_text_type(mod_index.dump_to_string())
             ret.append(module)
         return ret
 
@@ -91,16 +124,18 @@ class MBS(object):
 
         new_modules = []
         for module in modules:
-            mmd = Modulemd.Module.new_from_string(module['modulemd'])
-            mmd.upgrade()
+            mmd = Modulemd.ModuleStream.read_string(
+                module['modulemd'], strict=True, module_name=None, module_stream=None
+            )
+            mmd = mmd.upgrade(2)
 
             # Check runtime dependency (name:stream) of a module and if this
             # dependency is already in module_map/new_modules, do nothing.
             # But otherwise get the latest module in this name:stream from MBS
             # and add it to new_modules/module_map.
             for deps in mmd.get_dependencies():
-                for name, streams in deps.get_requires().items():
-                    for stream in streams.get():
+                for name in deps.get_runtime_modules():
+                    for stream in deps.get_runtime_streams(name):
                         key = "%s:%s" % (name, stream)
                         if key not in module_map:
                             new_module = self.get_latest_modules(key)
@@ -129,30 +164,37 @@ class MBS(object):
         new_modules = []
         # Temporary dict with "name:stream" as key and list of module dicts
         # as value.
-        module_map = {}
+        module_map = defaultdict(list)
 
         for module in modules:
             key = "%s:%s" % (module['name'], module['stream'])
 
-            # If this module is not in `new_modules` yet, add it there and
-            # continue to next module.
-            if key not in module_map:
-                module_map[key] = [module]
+            # In case this is the first module with this name:stream,
+            # just add it to new_modules.
+            old_modules = module_map[key]
+            if not old_modules:
+                module_map[key].append(module)
                 new_modules.append(module)
                 continue
 
             # Check if there is already this module in new_modules, but in
             # different version. If so, raise an exception.
-            old_modules = module_map[key]
-            if (module['version'] != old_modules[0]['version']):
+            if module['version'] != old_modules[0]['version']:
                 raise ModuleLookupError(
                     "%s:%s:%s:%s conflicts with %s:%s:%s:%s" % (
                         module['name'], module["stream"], module["version"],
                         module["context"], old_modules[0]['name'],
                         old_modules[0]["stream"], old_modules[0]["version"],
                         old_modules[0]["context"]))
-            else:
-                module_map[key].append(module)
+
+            # Check if there is already this module in new_modules in the very
+            # same context - do not add it there, because it would be duplicate.
+            if module['context'] in [m["context"] for m in old_modules]:
+                continue
+
+            # Add it to new_modules/module_map.
+            module_map[key].append(module)
+            new_modules.append(module)
 
         if expand:
             added_module_list = new_modules
