@@ -25,7 +25,6 @@
 """
 
 import os
-import glob
 
 from datetime import datetime, timedelta
 
@@ -161,7 +160,7 @@ class Compose(ODCSBase):
     celery_task_id = db.Column(db.String, nullable=True)
     # Target directory in which the compose is stored. This is `conf.target_dir`
     # by default.
-    target_dir = db.Column(db.String, nullable=True)
+    _target_dir = db.Column("target_dir", db.String, nullable=True)
 
     @property
     def on_default_target_dir(self):
@@ -170,6 +169,20 @@ class Compose(ODCSBase):
         """
         return self.target_dir is None or self.target_dir == conf.target_dir
 
+    @property
+    def target_dir(self):
+        """
+        Returns the `self._target_dir` if set, otherwise `conf.target_dir`.
+
+        This is needed to keep backward compatibility with composes which do
+        not have the `Compose.target_dir` set.
+        """
+        return self._target_dir or conf.target_dir
+
+    @target_dir.setter
+    def target_dir(self, value):
+        self._target_dir = value
+
     @classmethod
     def create(cls, session, owner, source_type, source, results,
                seconds_to_live, packages=None, flags=0, sigkeys=None,
@@ -205,7 +218,7 @@ class Compose(ODCSBase):
         return compose
 
     @classmethod
-    def create_copy(cls, session, compose, owner=None, seconds_to_live=None):
+    def create_copy(cls, session, compose, owner=None, seconds_to_live=None, sigkeys=None):
         """
         Creates new compose with all the options influencing the resulting
         compose copied from the `compose`. The `owner` and `seconds_to_live`
@@ -230,7 +243,7 @@ class Compose(ODCSBase):
             arches=compose.arches,
             multilib_arches=compose.multilib_arches,
             multilib_method=compose.multilib_method,
-            sigkeys=compose.sigkeys,
+            sigkeys=sigkeys if sigkeys is not None else compose.sigkeys,
             lookaside_repos=compose.lookaside_repos,
             modular_koji_tags=compose.modular_koji_tags,
             module_defaults_url=compose.module_defaults_url,
@@ -254,31 +267,16 @@ class Compose(ODCSBase):
         else:
             return "odcs-%d" % self.id
 
-    @property
-    def latest_dir(self):
-        return "latest-%s-1" % self.name
-
-    @property
-    def toplevel_work_dir(self):
-        # In case this compose failed, there won't be latest-* directory,
-        # but there might be the odcs-$id-1-$date.n.0 directory.
-        # The issue is that we cannot really know the date, because there is
-        # a race between we start Pungi and when Pungi generates that dir,
-        # so just use `glob` to find out the rigth directory.
-        glob_str = os.path.join(
-            self.target_dir, "odcs-%d-1-*.n.0" % self.id)
-        toplevel_dirs = glob.glob(glob_str)
-        if toplevel_dirs:
-            return toplevel_dirs[0]
-        return None
-
     @property
     def toplevel_dir(self):
-        if self.state == COMPOSE_STATES["failed"]:
-            toplevel_dir = self.toplevel_work_dir
-            if toplevel_dir:
-                return toplevel_dir
-        return os.path.join(self.target_dir, self.latest_dir)
+        return os.path.join(self.target_dir, self.name)
+
+    @property
+    def toplevel_url(self):
+        if not self.on_default_target_dir:
+            return ""
+
+        return conf.target_dir_url + "/" + self.name
 
     @property
     def result_repo_dir(self):
@@ -296,17 +294,15 @@ class Compose(ODCSBase):
         if not self.on_default_target_dir:
             return ""
 
-        target_dir_url = conf.target_dir_url
-
-        return target_dir_url + "/" \
-            + os.path.join(self.latest_dir, "compose", "Temporary")
+        return conf.target_dir_url + "/" \
+            + os.path.join(self.name, "compose", "Temporary")
 
     @property
     def result_repofile_path(self):
         """
         Returns path to .repo file.
         """
-        return os.path.join(self.toplevel_dir, "compose", "Temporary",
+        return os.path.join(self.name, "compose", "Temporary",
                             self.name + ".repo")
 
     @property
@@ -317,9 +313,8 @@ class Compose(ODCSBase):
         if not self.on_default_target_dir:
             return ""
 
-        target_dir_url = conf.target_dir_url
-        return target_dir_url + "/" \
-            + os.path.join(self.latest_dir, "compose", "Temporary",
+        return conf.target_dir_url + "/" \
+            + os.path.join(self.name, "compose", "Temporary",
                            self.name + ".repo")
 
     @validates('state')
@@ -367,6 +362,7 @@ class Compose(ODCSBase):
             'removed_by': self.removed_by,
             'result_repo': self.result_repo_url,
             'result_repofile': self.result_repofile_url,
+            'toplevel_url': self.toplevel_url,
             'flags': flags,
             'results': results,
             'sigkeys': self.sigkeys if self.sigkeys else "",
