@@ -347,15 +347,12 @@ class Pungi(object):
             pungi_cmd += ["--old-composes", self.old_compose]
         return pungi_cmd
 
-    def _prepare_compose_dir(self, compose, conf_topdir, targetdir):
+    def _prepare_compose_dir(self, compose, conf_topdir):
         """
         Creates the compose directory and returns the full path to it.
         """
         compose_date = time.strftime("%Y%m%d", time.localtime())
-        compose_id = "odcs-%s-1-%s.n.0" % (
-            self.compose_id, compose_date)
-        compose_dir = os.path.join(targetdir, compose_id)
-        makedirs(compose_dir)
+        makedirs(compose.toplevel_dir)
 
         conf = PyConfigParser()
         conf.load_from_file(os.path.join(conf_topdir, "pungi.conf"))
@@ -387,13 +384,13 @@ class Pungi(object):
             ci.compose.respin += 1
 
         # Dump the compose info to work/global/composeinfo-base.json.
-        work_dir = os.path.join(compose_dir, "work", "global")
+        work_dir = os.path.join(compose.toplevel_dir, "work", "global")
         makedirs(work_dir)
         ci.dump(os.path.join(work_dir, "composeinfo-base.json"))
 
         compose.pungi_compose_id = ci.compose.id
 
-        return compose_dir
+        return compose.toplevel_dir
 
     def run_locally(self, compose):
         """
@@ -403,7 +400,7 @@ class Pungi(object):
         try:
             td = tempfile.mkdtemp()
             self._write_cfgs(td)
-            compose_dir = self._prepare_compose_dir(compose, td, compose.target_dir)
+            compose_dir = self._prepare_compose_dir(compose, td)
             self.pungi_cfg.validate(td, compose_dir)
             pungi_cmd = self.get_pungi_cmd(td, compose.target_dir, compose_dir)
 
@@ -449,22 +446,22 @@ class PungiLogs(object):
         """
         Returns the path to pungi.global.log if it exists.
         """
-        toplevel_work_dir = self.compose.toplevel_work_dir
-        if not toplevel_work_dir:
+        toplevel_dir = self.compose.toplevel_dir
+        if not toplevel_dir:
             return None
         return os.path.join(
-            toplevel_work_dir, "logs", "global", "pungi.global.log")
+            toplevel_dir, "logs", "global", "pungi.global.log")
 
     @property
     def config_dump_path(self):
         """
         Returns path to Pungi config dump.
         """
-        toplevel_work_dir = self.compose.toplevel_work_dir
-        if not toplevel_work_dir:
+        toplevel_dir = self.compose.toplevel_dir
+        if not toplevel_dir:
             return None
         return os.path.join(
-            toplevel_work_dir, "logs", "global", "config-dump.global.log")
+            toplevel_dir, "logs", "global", "config-dump.global.log")
 
     def _get_global_log_errors(self):
         """
@@ -481,7 +478,7 @@ class PungiLogs(object):
         try:
             with open(global_log_path, "r") as global_log:
                 error = ""
-                for line in global_log.readlines():
+                for line in global_log:
                     idx = line.find("[ERROR   ]")
                     if idx == -1:
                         if error:
@@ -510,6 +507,10 @@ class PungiLogs(object):
             if error.startswith("Extended traceback in:"):
                 continue
             errors += error
+            if len(errors) > 2000:
+                errors = errors[:2000]
+                errors += " ...\n Too many errors, see Pungi log for more information."
+                break
 
         if self.compose.on_default_target_dir:
             errors = errors.replace(
