@@ -166,6 +166,8 @@ class ODCSAPI(MethodView):
 
         :query number id: :ref:`ID<id>` of the compose to update/regenerate.
         :jsonparam number seconds_to_live: Number of seconds before the compoose expires.
+        :jsonparam list sigkeys: Optional list defining the :ref:`sigkeys<sigkeys>`.
+            If not defined, original :ref:`sigkeys<sigkeys>` will be used.
 
         :statuscode 200: Compose updated and returned.
         :statuscode 401: User is unathorized.
@@ -196,19 +198,33 @@ class ODCSAPI(MethodView):
         # when regenerating them.
         compose_type = old_compose.compose_type or "test"
 
+        sigkeys = ""
+        if "sigkeys" in data:
+            sigkeys = ' '.join(data["sigkeys"])
+        else:
+            sigkeys = old_compose.sigkeys
+
+        # Get the raw_config_key if this compose is RAW_CONFIG.
+        raw_config_key = None
+        if old_compose.source_type == PungiSourceType.RAW_CONFIG:
+            raw_config_key = old_compose.source.split("#")[0]
+
         raise_if_input_not_allowed(
             source_types=old_compose.source_type, sources=old_compose.source,
             results=old_compose.results, flags=old_compose.flags,
-            arches=old_compose.arches, compose_types=compose_type)
+            arches=old_compose.arches, compose_types=compose_type,
+            raw_config_keys=raw_config_key)
 
-        has_to_create_a_copy = old_compose.state in (
-            COMPOSE_STATES['removed'], COMPOSE_STATES['failed'])
+        has_to_create_a_copy = (
+            old_compose.state in (COMPOSE_STATES['removed'], COMPOSE_STATES['failed']) or
+            sigkeys != old_compose.sigkeys)
         if has_to_create_a_copy:
             log.info("%r: Going to regenerate the compose", old_compose)
             compose = Compose.create_copy(db.session,
                                           old_compose,
                                           self._get_compose_owner(),
-                                          seconds_to_live)
+                                          seconds_to_live,
+                                          sigkeys=sigkeys)
             db.session.add(compose)
             # Flush is needed, because we use `before_commit` SQLAlchemy
             # event to send message and before_commit can be called before
@@ -218,9 +234,13 @@ class ODCSAPI(MethodView):
 
             if CELERY_AVAILABLE and conf.celery_broker_url:
                 if compose.source_type == PungiSourceType.PULP:
-                    generate_pulp_compose.delay(compose.id)
+                    result = generate_pulp_compose.delay(compose.id)
                 else:
-                    generate_pungi_compose.delay(compose.id)
+                    result = generate_pungi_compose.delay(compose.id)
+
+                compose.celery_task_id = result.id
+                db.session.add(compose)
+                db.session.commit()
 
             return jsonify(compose.json()), 200
         else:
@@ -308,6 +328,7 @@ class ODCSAPI(MethodView):
             raise ValueError(err)
 
         # Validate `source` based on `source_type`.
+        raw_config_key = None
         if source_type == PungiSourceType.RAW_CONFIG:
             if len(source) > 1:
                 raise ValueError(
@@ -326,6 +347,7 @@ class ODCSAPI(MethodView):
                 raise ValueError(
                     'Source "%s" does not exist in server configuration.' %
                     source_name)
+            raw_config_key = source_name
         elif source_type == PungiSourceType.MODULE:
             for module_str in source:
                 nsvc = module_str.split(":")
@@ -426,7 +448,7 @@ class ODCSAPI(MethodView):
         raise_if_input_not_allowed(
             source_types=source_type, sources=source, results=results,
             flags=flags, arches=arches, compose_types=compose_type,
-            target_dirs=target_dir)
+            target_dirs=target_dir, raw_config_keys=raw_config_key)
 
         compose = Compose.create(
             db.session, self._get_compose_owner(), source_type, source,
@@ -542,15 +564,19 @@ class AboutAPI(MethodView):
             - ``openidc`` - OpenIDC authorization is required.
             - ``kerberos_or_ssl`` - Kerberos or SSL authorization is required.
             - ``ssl`` - SSL authorization is required.
+        :resjson dict allowed_clients: Allowed clients in the same format as
+            in the ODCS server configuration file.
+        :resjson dict raw_config_urls: Raw config URLs in the same format as
+            in the ODCS server configuration file.
         :statuscode 200: Compose updated and returned.
         """
         json = {'version': version}
-        config_items = ['auth_backend']
+        config_items = ['auth_backend', 'allowed_clients', 'raw_config_urls']
         for item in config_items:
             config_item = getattr(conf, item)
             # All config items have a default, so if doesn't exist it is
             # an error
-            if not config_item:
+            if config_item is None:
                 raise ValueError(
                     'An invalid config item of "%s" was specified' % item)
             json[item] = config_item
