@@ -488,6 +488,7 @@ class TestBackend(ModelsBaseTest):
                     "content_set": "foo-1",
                     "arch": "x86_64",
                     "signatures": "SIG1,SIG2",
+                    "product_versions": "",
                 },
             },
             {
@@ -496,6 +497,7 @@ class TestBackend(ModelsBaseTest):
                     "content_set": "foo-2",
                     "arch": "x86_64",
                     "signatures": "SIG1,SIG2",
+                    "product_versions": "",
                 }
             },
             {
@@ -504,6 +506,7 @@ class TestBackend(ModelsBaseTest):
                     "content_set": "foo-3",
                     "arch": "ppc64",
                     "signatures": "SIG1,SIG3",
+                    "product_versions": "",
                 }
             }
         ]
@@ -557,8 +560,9 @@ gpgcheck=0
 
     @patch("odcs.server.pulp.Pulp._rest_post")
     @patch("odcs.server.backend._write_repo_file")
+    @patch("os.symlink")
     def test_generate_pulp_compose_include_inpublished_pulp_repos_passed(
-            self, _write_repo_file, pulp_rest_post):
+            self, symlink, _write_repo_file, pulp_rest_post):
         pulp_rest_post.return_value = [
             {
                 "notes": {
@@ -591,6 +595,7 @@ gpgcheck=0
         }
         pulp_rest_post.assert_called_once_with('repositories/search/',
                                                expected_query)
+        symlink.assert_not_called()
 
     @patch("odcs.server.pulp.Pulp._rest_post")
     @patch("odcs.server.backend._write_repo_file")
@@ -602,7 +607,8 @@ gpgcheck=0
                     "relative_url": "content/1/x86_64/os",
                     "content_set": "foo-1",
                     "arch": "ppc64",
-                    "signatures": "SIG1,SIG2"
+                    "signatures": "SIG1,SIG2",
+                    "product_versions": "",
                 },
             },
         ]
@@ -645,7 +651,8 @@ gpgcheck=0
                     "relative_url": "content/1/x86_64/os",
                     "content_set": "foo-1",
                     "arch": "ppc64",
-                    "signatures": "SIG1,SIG2"
+                    "signatures": "SIG1,SIG2",
+                    "product_versions": "",
                 },
             },
         ]
@@ -1026,9 +1033,9 @@ class TestGeneratePungiCompose(ModelsBaseTest):
 
         makedirs.assert_called_once_with(AnyStringWith("/test_composes/production"))
         symlink.assert_has_calls([
-            call('../odcs-1-2018-1',
+            call('../odcs-1',
                  AnyStringWith('/test_composes/production/compose-1-10-2020110.n.0')),
-            call('../odcs-1-2018-1',
+            call('../odcs-1',
                  AnyStringWith('/test_composes/production/latest-compose-1')),
         ])
         unlink.assert_called_with(
@@ -1046,6 +1053,10 @@ class TestValidatePungiCompose(ModelsBaseTest):
             COMPOSE_RESULTS["repository"], 60, packages='pkg1 pkg2 pkg3')
         db.session.commit()
 
+        # Remove any previous toplevel_dir.
+        if os.path.exists(self.c.toplevel_dir):
+            shutil.rmtree(self.c.toplevel_dir)
+
         compose_dir = os.path.join(self.c.toplevel_dir, 'compose')
         metadata_dir = os.path.join(compose_dir, 'metadata')
         self.rpms_metadata = os.path.join(metadata_dir, 'rpms.json')
