@@ -276,8 +276,8 @@ class TestComposerThread(ModelsBaseTest):
         self.assertEqual(c.reused_id, 1)
         self.assertEqual(c.state, COMPOSE_STATES["done"])
         self.assertEqual(c.result_repo_dir,
-                         os.path.join(odcs.server.conf.target_dir, "latest-odcs-1-1/compose/Temporary"))
-        self.assertEqual(c.result_repo_url, "http://localhost/odcs/latest-odcs-1-1/compose/Temporary")
+                         os.path.join(odcs.server.conf.target_dir, "odcs-1/compose/Temporary"))
+        self.assertEqual(c.result_repo_url, "http://localhost/odcs/odcs-1/compose/Temporary")
 
     @patch("odcs.server.utils.execute_cmd")
     @patch("odcs.server.backend.create_koji_session")
@@ -301,8 +301,8 @@ class TestComposerThread(ModelsBaseTest):
         self.assertEqual(c.reused_id, None)
         self.assertEqual(c.state, COMPOSE_STATES["done"])
         self.assertEqual(c.result_repo_dir,
-                         os.path.join(odcs.server.conf.target_dir, "latest-odcs-2-1/compose/Temporary"))
-        self.assertEqual(c.result_repo_url, "http://localhost/odcs/latest-odcs-2-1/compose/Temporary")
+                         os.path.join(odcs.server.conf.target_dir, "odcs-2/compose/Temporary"))
+        self.assertEqual(c.result_repo_url, "http://localhost/odcs/odcs-2/compose/Temporary")
 
 
 class TestComposerThreadLostComposes(ModelsBaseTest):
