@@ -372,6 +372,7 @@ class TestPungi(ModelsBaseTest):
 
         self.compose = MagicMock()
         self.compose.target_dir = conf.target_dir
+        self.compose.toplevel_dir = os.path.join(conf.target_dir, "odcs-1")
         self.compose.compose_type = "test"
 
     def tearDown(self):
@@ -389,7 +390,7 @@ class TestPungi(ModelsBaseTest):
         pungi.run(self.compose)
 
         self.makedirs.assert_called_with(
-            AnyStringWith("test_composes/odcs-1-1-"))
+            AnyStringWith("test_composes/odcs-1/"))
         self.makedirs.assert_called_with(
             AnyStringWith("work/global"))
         self.ci_dump.assert_called_once_with(
@@ -422,7 +423,7 @@ class TestPungi(ModelsBaseTest):
             pungi.run(self.compose)
 
         self.makedirs.assert_called_with(
-            AnyStringWith("test_composes/odcs-1-1-"))
+            AnyStringWith("test_composes/odcs-1/"))
         self.makedirs.assert_called_with(
             AnyStringWith("work/global"))
         self.ci_dump.assert_called_once_with(
@@ -441,6 +442,8 @@ class TestPungi(ModelsBaseTest):
         compose = Compose.create(
             db.session, "me", PungiSourceType.RAW_CONFIG, "foo",
             COMPOSE_RESULTS["repository"], 3600)
+        db.session.add(compose)
+        db.session.commit()
 
         def mocked_execute_cmd(*args, **kwargs):
             topdir = kwargs["cwd"]
@@ -569,6 +572,20 @@ For more details see {0}/odcs-717-1-20180323.n.0/work/x86_64/pungi/Temporary.x86
             "Compose run failed: ERROR running command: pungi -G\n"
             "For more details see http://localhost/odcs/odcs-717-1-20180323.n.0/work/x86_64/pungi/Temporary.x86_64.log\n")
 
+    @patch("odcs.server.pungi.open", create=True)
+    def test_error_string_too_many_errors(self, patched_open):
+        pungi_log = """
+2018-03-23 03:38:42 [INFO    ] Writing pungi config
+2018-03-22 17:10:49 [ERROR   ] Compose run failed: No such entry in table tag: tag
+        """ * 100
+        patched_open.return_value = mock_open(
+            read_data=pungi_log).return_value
+
+        pungi_logs = PungiLogs(self.compose)
+        errors = pungi_logs.get_error_string()
+        self.assertTrue("Too many errors" in errors)
+        self.assertEqual(len(errors), 2058)
+
     @patch("odcs.server.pungi.open", create=True)
     def test_error_string_no_error(self, patched_open):
         pungi_log = """
@@ -589,7 +606,6 @@ For more details see {0}/odcs-717-1-20180323.n.0/work/x86_64/pungi/Temporary.x86
 
     def test_toplevel_work_dir(self):
         # The self.glob is inherited from ModelsBaseTest.
-        self.glob.return_value = []
         pungi_logs = PungiLogs(self.compose)
         errors = pungi_logs.get_error_string()
         self.assertEqual(errors, "")
