@@ -121,7 +121,11 @@ class ViewBaseTest(ModelsBaseTest):
                 'dev3': {
                     'source_types': ['tag'],
                     'target_dirs': ["releng-private"]
-                }
+                },
+                'dev4': {
+                    'source_types': ['raw_config'],
+                    'raw_config_keys': ["pungi_cfg2"]
+                },
             }
         }
         patched_admins = {'groups': ['admin'], 'users': ['root']}
@@ -266,7 +270,9 @@ class TestViews(ViewBaseTest):
         rv = self.client.get('/api/1/about/')
         data = json.loads(rv.get_data(as_text=True))
         self.assertEqual(
-            data, {'version': version, 'auth_backend': 'noauth'})
+            data,
+            {'version': version, 'auth_backend': 'noauth', 'raw_config_urls': {},
+             'allowed_clients': odcs.server.auth.conf.allowed_clients})
 
     def test_submit_invalid_json(self):
         with self.test_request_context(user='dev'):
@@ -297,8 +303,8 @@ class TestViews(ViewBaseTest):
                          'state_reason': None,
                          'source': u'testmodule:master',
                          'owner': u'dev',
-                         'result_repo': 'http://localhost/odcs/latest-odcs-%d-1/compose/Temporary' % data['id'],
-                         'result_repofile': 'http://localhost/odcs/latest-odcs-%d-1/compose/Temporary/odcs-%d.repo' % (data['id'], data['id']),
+                         'result_repo': 'http://localhost/odcs/odcs-%d/compose/Temporary' % data['id'],
+                         'result_repofile': 'http://localhost/odcs/odcs-%d/compose/Temporary/odcs-%d.repo' % (data['id'], data['id']),
                          'time_submitted': data["time_submitted"], 'id': data['id'],
                          'time_started': None,
                          'time_removed': None,
@@ -320,7 +326,8 @@ class TestViews(ViewBaseTest):
                          'label': None,
                          'compose_type': 'test',
                          'pungi_compose_id': None,
-                         'target_dir': 'default'}
+                         'target_dir': 'default',
+                         'toplevel_url': 'http://localhost/odcs/odcs-%d' % data['id']}
         self.assertEqual(data, expected_json)
 
         db.session.expire_all()
@@ -700,6 +707,43 @@ class TestViews(ViewBaseTest):
         c = db.session.query(Compose).filter(Compose.id == 3).one()
         self.assertEqual(c.reused_id, None)
 
+    def test_submit_build_resurrection_not_allowed_raw_config_key(self):
+        self.c1.state = COMPOSE_STATES["removed"]
+        self.c1.reused_id = 1
+        self.c1.source_type = 5
+        self.c1.source = "pungi_cfg#hash"
+        db.session.commit()
+
+        with self.test_request_context(user='dev4'):
+            flask.g.oidc_scopes = [
+                '{0}{1}'.format(conf.oidc_base_namespace, 'renew-compose')
+            ]
+
+            rv = self.client.patch('/api/1/composes/1')
+            data = json.loads(rv.get_data(as_text=True))
+
+        self.assertEqual(
+            data["message"],
+            "User dev4 not allowed to operate with compose with raw_config_keys=pungi_cfg.")
+
+    def test_submit_build_resurrection_allowed_raw_config_key(self):
+        self.c1.state = COMPOSE_STATES["removed"]
+        self.c1.reused_id = 1
+        self.c1.source_type = 5
+        self.c1.source = "pungi_cfg2#hash"
+        db.session.commit()
+
+        with self.test_request_context(user='dev4'):
+            flask.g.oidc_scopes = [
+                '{0}{1}'.format(conf.oidc_base_namespace, 'renew-compose')
+            ]
+
+            rv = self.client.patch('/api/1/composes/1')
+            data = json.loads(rv.get_data(as_text=True))
+
+        self.assertEqual(data['id'], 3)
+        self.assertEqual(data['state_name'], 'wait')
+
     def test_submit_build_resurrection_failed(self):
         self.c1.state = COMPOSE_STATES["failed"]
         self.c1.reused_id = 1
@@ -743,6 +787,53 @@ class TestViews(ViewBaseTest):
 
         self.assertEqual(data['message'], 'No compose with id 100 found')
 
+    def test_submit_build_resurrection_removed_new_sigkeys(self):
+        self.c1.state = COMPOSE_STATES["removed"]
+        self.c1.reused_id = 1
+        db.session.commit()
+
+        with self.test_request_context(user='dev'):
+            flask.g.oidc_scopes = [
+                '{0}{1}'.format(conf.oidc_base_namespace, 'renew-compose')
+            ]
+
+            rv = self.client.patch('/api/1/composes/1', data=json.dumps(
+                {"sigkeys": ["123", "456"]}))
+            data = json.loads(rv.get_data(as_text=True))
+
+        self.assertEqual(data['id'], 3)
+        self.assertEqual(data['state_name'], 'wait')
+        self.assertEqual(data['source'], 'testmodule:master')
+        self.assertEqual(data['sigkeys'], '123 456')
+        self.assertEqual(data['time_removed'], None)
+
+        c = db.session.query(Compose).filter(Compose.id == 3).one()
+        self.assertEqual(c.reused_id, None)
+
+    def test_submit_build_resurrection_done_new_sigkeys(self):
+        self.c1.state = COMPOSE_STATES["done"]
+        self.c1.reused_id = 1
+        self.c1.sigkeys = "012 345"
+        db.session.commit()
+
+        with self.test_request_context(user='dev'):
+            flask.g.oidc_scopes = [
+                '{0}{1}'.format(conf.oidc_base_namespace, 'renew-compose')
+            ]
+
+            rv = self.client.patch('/api/1/composes/1', data=json.dumps(
+                {"sigkeys": ["123", "456"]}))
+            data = json.loads(rv.get_data(as_text=True))
+
+        self.assertEqual(data['id'], 3)
+        self.assertEqual(data['state_name'], 'wait')
+        self.assertEqual(data['source'], 'testmodule:master')
+        self.assertEqual(data['sigkeys'], '123 456')
+        self.assertEqual(data['time_removed'], None)
+
+        c = db.session.query(Compose).filter(Compose.id == 3).one()
+        self.assertEqual(c.reused_id, None)
+
     def test_submit_build_not_allowed_source_type(self):
         with self.test_request_context(user='dev'):
             flask.g.oidc_scopes = [
@@ -774,6 +865,38 @@ class TestViews(ViewBaseTest):
             data['message'],
             'User dev2 not allowed to operate with compose with compose_types=production.')
 
+    @patch.object(odcs.server.config.Config, 'raw_config_urls',
+                  new={"pungi_cfg": "http://localhost/pungi.conf#%s"})
+    def test_submit_build_not_allowed_raw_config_key(self):
+        with self.test_request_context(user='dev4'):
+            flask.g.oidc_scopes = [
+                '{0}{1}'.format(conf.oidc_base_namespace, 'new-compose')
+            ]
+
+            rv = self.client.post('/api/1/composes/', data=json.dumps(
+                {'source': {'type': 'raw_config', 'source': 'pungi_cfg#hash'},
+                 'compose_type': 'production'}))
+            data = json.loads(rv.get_data(as_text=True))
+
+        self.assertEqual(
+            data['message'],
+            'User dev4 not allowed to operate with compose with raw_config_keys=pungi_cfg.')
+
+    @patch.object(odcs.server.config.Config, 'raw_config_urls',
+                  new={"pungi_cfg2": "http://localhost/pungi.conf#%s"})
+    def test_submit_build_allowed_raw_config_key(self):
+        with self.test_request_context(user='dev4'):
+            flask.g.oidc_scopes = [
+                '{0}{1}'.format(conf.oidc_base_namespace, 'new-compose')
+            ]
+
+            rv = self.client.post('/api/1/composes/', data=json.dumps(
+                {'source': {'type': 'raw_config', 'source': 'pungi_cfg2#hash'},
+                 'compose_type': 'production'}))
+            data = json.loads(rv.get_data(as_text=True))
+
+        self.assertEqual(data["source"], "pungi_cfg2#hash")
+
     def test_submit_build_unknown_source_type(self):
         with self.test_request_context(user='dev'):
             flask.g.oidc_scopes = [
@@ -1203,8 +1326,8 @@ class TestViews(ViewBaseTest):
                          'state_reason': None,
                          'source': u'testmodule:master',
                          'owner': u'unknown',
-                         'result_repo': 'http://localhost/odcs/latest-odcs-%d-1/compose/Temporary' % data['id'],
-                         'result_repofile': 'http://localhost/odcs/latest-odcs-%d-1/compose/Temporary/odcs-%d.repo' % (data['id'], data['id']),
+                         'result_repo': 'http://localhost/odcs/odcs-%d/compose/Temporary' % data['id'],
+                         'result_repofile': 'http://localhost/odcs/odcs-%d/compose/Temporary/odcs-%d.repo' % (data['id'], data['id']),
                          'time_submitted': data["time_submitted"], 'id': data['id'],
                          'time_started': None,
                          'time_removed': None,
@@ -1226,7 +1349,8 @@ class TestViews(ViewBaseTest):
                          'label': None,
                          'compose_type': 'test',
                          'pungi_compose_id': None,
-                         'target_dir': 'default'}
+                         'target_dir': 'default',
+                         'toplevel_url': 'http://localhost/odcs/odcs-%d' % data['id']}
         self.assertEqual(data, expected_json)
 
         db.session.expire_all()
